@@ -31,7 +31,7 @@ options = parser.parse_args()
 # Create sample file if not exists
 config_dir = Utils.get_project_root()
 sample_file = config_dir.joinpath(pathlib.PurePath('sample.config.yaml'))
-real_file = config_dir.joinpath(pathlib.PurePath('sample.config.yaml'))
+real_file = config_dir.joinpath(pathlib.PurePath('config.yaml'))
 if (not os.path.isfile(sample_file) and not os.path.isfile(real_file)) or options.generate_config:
     ref_file = pathlib.Path(__file__).parent.joinpath(pathlib.PurePath('sample.config.yaml'))
     shutil.copyfile(ref_file, sample_file)
